DWD Classifiers
===============

.. autoclass:: dwd.DWD
   :members: fit
   :inherited-members: predict, decision_function, score

.. autoclass:: dwd.GenDWD

.. autoclass:: dwd.KernGDWD

Cross-validation
----------------

.. autoclass:: dwd.GenDWDCV

.. autoclass:: dwd.KernGDWDCV
